@@ -77,7 +77,7 @@ class Article(object):
     def bagOfWords(self, annotation):
         b = set()
         for s in self.sentences:
-            b.union(s.bagOfWords(annotation))
+            b = b.union(b, s.bagOfWords(annotation))
         return b
 
     def display(self):
@@ -97,7 +97,7 @@ class Subcorpus(object):
     def bagOfWords(self, annotation):
         b = set()
         for a in self.articles:
-            b.union(a.bagOfWords(annotation))
+            b = b.union(b, s.bagOfWords(annotation))
         return b
 
     def read (self, infile):
